[clang] [clang-tools-extra] [flang] [lldb] [llvm] [mlir] Fix typos: paramter, parametr, parametere (PR #134092)
via llvm-commits
llvm-commits at lists.llvm.org
Wed Apr 2 07:37:32 PDT 2025
llvmbot wrote:
<!--LLVM PR SUMMARY COMMENT-->
@llvm/pr-subscribers-clang-format
@llvm/pr-subscribers-backend-webassembly
Author: Jay Foad (jayfoad)
<details>
<summary>Changes</summary>
---
Patch is 24.76 KiB, truncated to 20.00 KiB below, full version: https://github.com/llvm/llvm-project/pull/134092.diff
30 Files Affected:
- (modified) bolt/utils/bughunter.sh (+1-1)
- (modified) clang-tools-extra/clangd/SemanticHighlighting.cpp (+1-1)
- (modified) clang/docs/ReleaseNotes.rst (+2-2)
- (modified) clang/include/clang/Basic/AttrDocs.td (+1-1)
- (modified) clang/include/clang/Basic/DiagnosticASTKinds.td (+1-1)
- (modified) clang/include/clang/Basic/arm_cde.td (+1-1)
- (modified) clang/lib/AST/ByteCode/Compiler.cpp (+2-1)
- (modified) clang/lib/Analysis/UnsafeBufferUsage.cpp (+1-1)
- (modified) clang/lib/CodeGen/CodeGenFunction.h (+1-1)
- (modified) clang/lib/CodeGen/TargetBuiltins/ARM.cpp (+1-1)
- (modified) clang/lib/StaticAnalyzer/Checkers/RetainCountChecker/RetainCountDiagnostics.cpp (+1-1)
- (modified) clang/lib/StaticAnalyzer/Checkers/StdLibraryFunctionsChecker.cpp (+1-1)
- (modified) clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.cpp (+1-1)
- (modified) clang/test/Modules/odr_hash.cpp (+3-3)
- (modified) clang/unittests/Format/FormatTest.cpp (+2-2)
- (modified) flang/lib/Lower/OpenMP/PrivateReductionUtils.cpp (+1-1)
- (modified) flang/lib/Optimizer/CodeGen/TypeConverter.cpp (+1-1)
- (modified) lldb/source/Plugins/Platform/Windows/PlatformWindows.cpp (+1-1)
- (modified) llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.cpp (+3-3)
- (modified) llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.h (+2-2)
- (modified) llvm/lib/Transforms/IPO/MemProfContextDisambiguation.cpp (+1-1)
- (modified) llvm/test/CodeGen/AArch64/sched-movprfx.ll (+1-1)
- (modified) llvm/test/CodeGen/AArch64/sve2-intrinsics-fp-int-binary-logarithm-zeroing.ll (+1-1)
- (modified) llvm/test/MC/WebAssembly/block-assembly.s (+1-1)
- (modified) llvm/unittests/DebugInfo/DWARF/DWARFFormValueTest.cpp (+1-1)
- (modified) mlir/include/mlir/Analysis/Presburger/PWMAFunction.h (+1-1)
- (modified) mlir/include/mlir/Dialect/Transform/IR/TransformOps.td (+1-1)
- (modified) mlir/include/mlir/TableGen/Class.h (+2-2)
- (modified) mlir/lib/Target/LLVMIR/Dialect/NVVM/NVVMToLLVMIRTranslation.cpp (+1-1)
- (modified) mlir/tools/mlir-linalg-ods-gen/mlir-linalg-ods-yaml-gen.cpp (+1-1)
``````````diff
diff --git a/bolt/utils/bughunter.sh b/bolt/utils/bughunter.sh
index c5dddc41fb41f..d5ce0592708e2 100755
--- a/bolt/utils/bughunter.sh
+++ b/bolt/utils/bughunter.sh
@@ -28,7 +28,7 @@
#
# TIMEOUT_OR_CMD - optional timeout or command on optimized binary command
# if the value is a number with an optional trailing letter
-# [smhd] it is considered a paramter to "timeout",
+# [smhd] it is considered a parameter to "timeout",
# otherwise it's a shell command that wraps the optimized
# binary command.
#
diff --git a/clang-tools-extra/clangd/SemanticHighlighting.cpp b/clang-tools-extra/clangd/SemanticHighlighting.cpp
index 86ca05644c703..1e9ca0ae7822d 100644
--- a/clang-tools-extra/clangd/SemanticHighlighting.cpp
+++ b/clang-tools-extra/clangd/SemanticHighlighting.cpp
@@ -876,7 +876,7 @@ class CollectExtraHighlightings
if (auto *ProtoType = FD->getType()->getAs<FunctionProtoType>()) {
// Iterate over the types of the function parameters.
- // If any of them are non-const reference paramteres, add it as a
+ // If any of them are non-const reference parameteres, add it as a
// highlighting modifier to the corresponding expression
for (size_t I = 0;
I < std::min(size_t(ProtoType->getNumParams()), Args.size()); ++I) {
diff --git a/clang/docs/ReleaseNotes.rst b/clang/docs/ReleaseNotes.rst
index 7978df0cc71cc..881bcd7415edd 100644
--- a/clang/docs/ReleaseNotes.rst
+++ b/clang/docs/ReleaseNotes.rst
@@ -381,12 +381,12 @@ Bug Fixes to C++ Support
now also works if the constraint has non-type or template template parameters.
(#GH131798)
- Fixes matching of nested template template parameters. (#GH130362)
-- Correctly diagnoses template template paramters which have a pack parameter
+- Correctly diagnoses template template parameters which have a pack parameter
not in the last position.
- Clang now correctly parses ``if constexpr`` expressions in immediate function context. (#GH123524)
- Fixed an assertion failure affecting code that uses C++23 "deducing this". (#GH130272)
- Clang now properly instantiates destructors for initialized members within non-delegating constructors. (#GH93251)
-- Correctly diagnoses if unresolved using declarations shadows template paramters (#GH129411)
+- Correctly diagnoses if unresolved using declarations shadows template parameters (#GH129411)
- Fixed C++20 aggregate initialization rules being incorrectly applied in certain contexts. (#GH131320)
- Clang was previously coalescing volatile writes to members of volatile base class subobjects.
The issue has been addressed by propagating qualifiers during derived-to-base conversions in the AST. (#GH127824)
diff --git a/clang/include/clang/Basic/AttrDocs.td b/clang/include/clang/Basic/AttrDocs.td
index a52ece467ec70..10bf28957d861 100644
--- a/clang/include/clang/Basic/AttrDocs.td
+++ b/clang/include/clang/Basic/AttrDocs.td
@@ -3418,7 +3418,7 @@ def M68kRTDDocs : Documentation {
let Content = [{
On M68k targets, this attribute changes the calling convention of a function
to clear parameters off the stack on return. In other words, callee is
-responsible for cleaning out the stack space allocated for incoming paramters.
+responsible for cleaning out the stack space allocated for incoming parameters.
This convention does not support variadic calls or unprototyped functions in C.
When targeting M68010 or newer CPUs, this calling convention is implemented
using the `rtd` instruction.
diff --git a/clang/include/clang/Basic/DiagnosticASTKinds.td b/clang/include/clang/Basic/DiagnosticASTKinds.td
index 8d69a2f2cf4a3..91f7ae86f3487 100644
--- a/clang/include/clang/Basic/DiagnosticASTKinds.td
+++ b/clang/include/clang/Basic/DiagnosticASTKinds.td
@@ -780,7 +780,7 @@ def note_module_odr_violation_record : Note<"but in '%0' found "
"friend %2|"
"friend function %2|"
"function template %2 with %3 template parameter%s3|"
- "function template %2 with %ordinal3 template paramter being a "
+ "function template %2 with %ordinal3 template parameter being a "
"%select{type|non-type|template}4 template parameter|"
"function template %2 with %ordinal3 template parameter "
"%select{with no name|named %5}4|"
diff --git a/clang/include/clang/Basic/arm_cde.td b/clang/include/clang/Basic/arm_cde.td
index 6a00e669864c8..a28565bb131cb 100644
--- a/clang/include/clang/Basic/arm_cde.td
+++ b/clang/include/clang/Basic/arm_cde.td
@@ -161,7 +161,7 @@ let pnt = PNT_Type, params = T.All, polymorphicOnly = 1 in {
}
// Reinterpret intrinsics required to implement __arm_vcx*q with 2 or 3
-// polymorphic paramters.
+// polymorphic parameters.
let params = [/* no u8 */ s8, u16, s16, u32, s32, u64, s64, f16, f32],
headerOnly = 1, polymorphicOnly = 1 in
def vreinterpretq_u8 :
diff --git a/clang/lib/AST/ByteCode/Compiler.cpp b/clang/lib/AST/ByteCode/Compiler.cpp
index 021acbd798646..09a4c08963d3c 100644
--- a/clang/lib/AST/ByteCode/Compiler.cpp
+++ b/clang/lib/AST/ByteCode/Compiler.cpp
@@ -4935,7 +4935,8 @@ bool Compiler<Emitter>::VisitCallExpr(const CallExpr *E) {
if (!this->visit(Arg))
return false;
- // If we know the callee already, check the known parametrs for nullability.
+ // If we know the callee already, check the known parameters for
+ // nullability.
if (FuncDecl && NonNullArgs[ArgIndex]) {
PrimType ArgT = classify(Arg).value_or(PT_Ptr);
if (ArgT == PT_Ptr || ArgT == PT_FnPtr) {
diff --git a/clang/lib/Analysis/UnsafeBufferUsage.cpp b/clang/lib/Analysis/UnsafeBufferUsage.cpp
index 776cbf6196b60..23f5f32cdcdf4 100644
--- a/clang/lib/Analysis/UnsafeBufferUsage.cpp
+++ b/clang/lib/Analysis/UnsafeBufferUsage.cpp
@@ -3601,7 +3601,7 @@ createOverloadsForFixedParams(const FixitStrategy &S, const FunctionDecl *FD,
// If a parameter of a function definition has no name:
return std::nullopt;
if (ParmsMask[i])
- // This is our spanified paramter!
+ // This is our spanified parameter!
SS << NewTysTexts[i] << "(" << Parm->getIdentifier()->getName().str()
<< ", " << getUserFillPlaceHolder("size") << ")";
else
diff --git a/clang/lib/CodeGen/CodeGenFunction.h b/clang/lib/CodeGen/CodeGenFunction.h
index dd73d3b3a75f3..cbb500aa81996 100644
--- a/clang/lib/CodeGen/CodeGenFunction.h
+++ b/clang/lib/CodeGen/CodeGenFunction.h
@@ -4002,7 +4002,7 @@ class CodeGenFunction : public CodeGenTypeCache {
const OMPTargetTeamsDistributeParallelForDirective &S);
/// Emit the Stmt \p S and return its topmost canonical loop, if any.
- /// TODO: The \p Depth paramter is not yet implemented and must be 1. In the
+ /// TODO: The \p Depth parameter is not yet implemented and must be 1. In the
/// future it is meant to be the number of loops expected in the loop nests
/// (usually specified by the "collapse" clause) that are collapsed to a
/// single loop by this function.
diff --git a/clang/lib/CodeGen/TargetBuiltins/ARM.cpp b/clang/lib/CodeGen/TargetBuiltins/ARM.cpp
index afe25b5418424..0c904442faab0 100644
--- a/clang/lib/CodeGen/TargetBuiltins/ARM.cpp
+++ b/clang/lib/CodeGen/TargetBuiltins/ARM.cpp
@@ -4316,7 +4316,7 @@ Value *CodeGenFunction::EmitSMEReadWrite(const SVETypeFlags &TypeFlags,
Value *CodeGenFunction::EmitSMEZero(const SVETypeFlags &TypeFlags,
SmallVectorImpl<Value *> &Ops,
unsigned IntID) {
- // svzero_za() intrinsic zeros the entire za tile and has no paramters.
+ // svzero_za() intrinsic zeros the entire za tile and has no parameters.
if (Ops.size() == 0)
Ops.push_back(llvm::ConstantInt::get(Int32Ty, 255));
Function *F = CGM.getIntrinsic(IntID, {});
diff --git a/clang/lib/StaticAnalyzer/Checkers/RetainCountChecker/RetainCountDiagnostics.cpp b/clang/lib/StaticAnalyzer/Checkers/RetainCountChecker/RetainCountDiagnostics.cpp
index 77258958ae027..4711dde62aebc 100644
--- a/clang/lib/StaticAnalyzer/Checkers/RetainCountChecker/RetainCountDiagnostics.cpp
+++ b/clang/lib/StaticAnalyzer/Checkers/RetainCountChecker/RetainCountDiagnostics.cpp
@@ -164,7 +164,7 @@ static bool shouldGenerateNote(llvm::raw_string_ostream &os,
return true;
}
-/// Finds argument index of the out paramter in the call @c S
+/// Finds argument index of the out parameter in the call @c S
/// corresponding to the symbol @c Sym.
/// If none found, returns std::nullopt.
static std::optional<unsigned>
diff --git a/clang/lib/StaticAnalyzer/Checkers/StdLibraryFunctionsChecker.cpp b/clang/lib/StaticAnalyzer/Checkers/StdLibraryFunctionsChecker.cpp
index 9c0b79ab58618..68bc92a8ca5fe 100644
--- a/clang/lib/StaticAnalyzer/Checkers/StdLibraryFunctionsChecker.cpp
+++ b/clang/lib/StaticAnalyzer/Checkers/StdLibraryFunctionsChecker.cpp
@@ -1510,7 +1510,7 @@ bool StdLibraryFunctionsChecker::Signature::matches(
// even in C++.
// In case of any non-C99 languages, we don't want to match based on the
// restrict qualifier because we cannot know if the given libc implementation
- // qualifies the paramter type or not.
+ // qualifies the parameter type or not.
auto RemoveRestrict = [&FD](QualType T) {
if (!FD->getASTContext().getLangOpts().C99)
T.removeLocalRestrict();
diff --git a/clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.cpp b/clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.cpp
index 7bc04ee565d03..8bb911eeb9347 100644
--- a/clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.cpp
+++ b/clang/lib/StaticAnalyzer/Checkers/WebKit/PtrTypesSemantics.cpp
@@ -620,7 +620,7 @@ class TrivialFunctionAnalysisVisitor
bool
VisitSubstNonTypeTemplateParmExpr(const SubstNonTypeTemplateParmExpr *E) {
- // Non-type template paramter is compile time constant and trivial.
+ // Non-type template parameter is compile time constant and trivial.
return true;
}
diff --git a/clang/test/Modules/odr_hash.cpp b/clang/test/Modules/odr_hash.cpp
index b0f5b904f2b39..fde37f1cc683f 100644
--- a/clang/test/Modules/odr_hash.cpp
+++ b/clang/test/Modules/odr_hash.cpp
@@ -3463,7 +3463,7 @@ struct S22 {
#else
S22 s22;
// expected-error at second.h:* {{'FunctionTemplate::S22' has different definitions in different modules; first difference is definition in module 'SecondModule' found function template 'foo' with 1st template parameter being a type template parameter}}
-// expected-note at first.h:* {{but in 'FirstModule' found function template 'foo' with 1st template paramter being a template template parameter}}
+// expected-note at first.h:* {{but in 'FirstModule' found function template 'foo' with 1st template parameter being a template template parameter}}
#endif
#if defined(FIRST)
@@ -3481,7 +3481,7 @@ struct S23 {
#else
S23 s23;
// expected-error at second.h:* {{'FunctionTemplate::S23' has different definitions in different modules; first difference is definition in module 'SecondModule' found function template 'foo' with 1st template parameter being a non-type template parameter}}
-// expected-note at first.h:* {{but in 'FirstModule' found function template 'foo' with 1st template paramter being a type template parameter}}
+// expected-note at first.h:* {{but in 'FirstModule' found function template 'foo' with 1st template parameter being a type template parameter}}
#endif
#if defined(FIRST)
@@ -3499,7 +3499,7 @@ struct S24 {
#else
S24 s24;
// expected-error at second.h:* {{'FunctionTemplate::S24' has different definitions in different modules; first difference is definition in module 'SecondModule' found function template 'foo' with 1st template parameter being a template template parameter}}
-// expected-note at first.h:* {{but in 'FirstModule' found function template 'foo' with 1st template paramter being a non-type template parameter}}
+// expected-note at first.h:* {{but in 'FirstModule' found function template 'foo' with 1st template parameter being a non-type template parameter}}
#endif
#if defined(FIRST)
diff --git a/clang/unittests/Format/FormatTest.cpp b/clang/unittests/Format/FormatTest.cpp
index 4dfa135120605..17194b77fe7b9 100644
--- a/clang/unittests/Format/FormatTest.cpp
+++ b/clang/unittests/Format/FormatTest.cpp
@@ -6733,7 +6733,7 @@ TEST_F(FormatTest, LayoutStatementsAroundPreprocessorDirectives) {
" withSomeParameters, whichInSequence,\n"
" areLongerThanALine(andAnotherCall,\n"
"#define A B\n"
- " withMoreParamters,\n"
+ " withMoreParameters,\n"
" whichStronglyInfluenceTheLayout),\n"
" andMoreParameters),\n"
" trailing);",
@@ -12304,7 +12304,7 @@ TEST_F(FormatTest, UnderstandsUsesOfStarAndAmp) {
verifyIndependentOfContext("f(b * /* confusing comment */ ++c);");
verifyFormat("f(* /* confusing comment */ foo);");
verifyFormat("void (* /*deleter*/)(const Slice &key, void *value)");
- verifyFormat("void foo(int * // this is the first paramters\n"
+ verifyFormat("void foo(int * // this is the first parameters\n"
" ,\n"
" int second);");
verifyFormat("double term = a * // first\n"
diff --git a/flang/lib/Lower/OpenMP/PrivateReductionUtils.cpp b/flang/lib/Lower/OpenMP/PrivateReductionUtils.cpp
index 268c7828ab56f..1faac7c7f6fe0 100644
--- a/flang/lib/Lower/OpenMP/PrivateReductionUtils.cpp
+++ b/flang/lib/Lower/OpenMP/PrivateReductionUtils.cpp
@@ -210,7 +210,7 @@ static void getLengthParameters(fir::FirOpBuilder &builder, mlir::Location loc,
mlir::Value moldArg,
llvm::SmallVectorImpl<mlir::Value> &lenParams) {
// We pass derived types unboxed and so are not self-contained entities.
- // Assume that unboxed derived types won't need length paramters.
+ // Assume that unboxed derived types won't need length parameters.
if (!hlfir::isFortranEntity(moldArg))
return;
diff --git a/flang/lib/Optimizer/CodeGen/TypeConverter.cpp b/flang/lib/Optimizer/CodeGen/TypeConverter.cpp
index 1a1d3a8cfb870..827d6def37e14 100644
--- a/flang/lib/Optimizer/CodeGen/TypeConverter.cpp
+++ b/flang/lib/Optimizer/CodeGen/TypeConverter.cpp
@@ -84,7 +84,7 @@ LLVMTypeConverter::LLVMTypeConverter(mlir::ModuleOp module, bool applyTBAA,
&getContext(), kindMapping.getIntegerBitsize(intTy.getFKind()));
});
addConversion([&](fir::LenType field) {
- // Get size of len paramter from the descriptor.
+ // Get size of len parameter from the descriptor.
return getModel<Fortran::runtime::typeInfo::TypeParameterValue>()(
&getContext());
});
diff --git a/lldb/source/Plugins/Platform/Windows/PlatformWindows.cpp b/lldb/source/Plugins/Platform/Windows/PlatformWindows.cpp
index c0c26cc5f1954..ab0e335c73d13 100644
--- a/lldb/source/Plugins/Platform/Windows/PlatformWindows.cpp
+++ b/lldb/source/Plugins/Platform/Windows/PlatformWindows.cpp
@@ -205,7 +205,7 @@ uint32_t PlatformWindows::DoLoadImage(Process *process,
}
name.emplace_back(L'\0');
- /* Inject name paramter into inferior */
+ /* Inject name parameter into inferior */
lldb::addr_t injected_name =
process->AllocateMemory(name.size() * sizeof(llvm::UTF16),
ePermissionsReadable | ePermissionsWritable,
diff --git a/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.cpp b/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.cpp
index b2089521c4674..d0a89d87f4894 100644
--- a/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.cpp
+++ b/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.cpp
@@ -75,7 +75,7 @@ bool PPCFunctionInfo::isLiveInZExt(Register VReg) const {
void PPCFunctionInfo::appendParameterType(ParamType Type) {
- ParamtersType.push_back(Type);
+ ParametersType.push_back(Type);
switch (Type) {
case FixedType:
++FixedParmsNum;
@@ -103,7 +103,7 @@ uint32_t PPCFunctionInfo::getVecExtParmsType() const {
if (!hasVectorParms())
return 0;
- for (const auto &Elt : ParamtersType) {
+ for (const auto &Elt : ParametersType) {
switch (Elt) {
case VectorChar:
VectExtParamInfo <<= XCOFF::TracebackTable::WidthOfParamType;
@@ -145,7 +145,7 @@ uint32_t PPCFunctionInfo::getParmsType() const {
unsigned ShiftBits = 32 - XCOFF::TracebackTable::WidthOfParamType;
int Bits = 0;
- for (const auto &Elt : ParamtersType) {
+ for (const auto &Elt : ParametersType) {
if (Bits > 31 || (Bits > 30 && (Elt != FixedType || hasVectorParms())))
break;
diff --git a/llvm/lib/Transforms/IPO/MemProfContextDisambiguation.cpp b/llvm/lib/Transforms/IPO/MemProfContextDisambiguation.cpp
index df1f6fddeba60..99200c8bbcdb3 100644
--- a/llvm/lib/Transforms/IPO/MemProfContextDisambiguation.cpp
+++ b/llvm/lib/Transforms/IPO/MemProfContextDisambiguation.cpp
@@ -2280,7 +2280,7 @@ void CallsiteContextGraph<DerivedCCG, FuncTy,
// We need to check all of the calls recorded in this Node, because in some
// cases we may have had multiple calls with the same debug info calling
// different callees. This can happen, for example, when an object is
- // constructed in the paramter list - the destructor call of the object has
+ // constructed in the parameter list - the destructor call of the object has
// the same debug info (line/col) as the call the object was passed to.
// Here we will prune any that don't match all callee nodes.
std::vector<CallInfo> AllCalls;
diff --git a/llvm/test/CodeGen/AArch64/sched-movprfx.ll b/llvm/test/CodeGen/AArch64/sched-movprfx.ll
index 9e88d1659d45f..c4f9768d9675e 100644
--- a/llvm/test/CodeGen/AArch64/sched-movprfx.ll
+++ b/llvm/test/CodeGen/AArch64/sched-movprfx.ll
@@ -6,7 +6,7 @@
; be preferentially issued.
-; NOTE: The unused paramter ensures z0/z1 is free, avoiding the antidependence for schedule.
+; NOTE: The unused parameter ensures z0/z1 is free, avoiding the antidependence for schedule.
define <vscale x 2 x i64> @and_i64_zero(<vscale x 2 x i1> %pg, <vscale x 2 x i64> %a, <vscale x 2 x i64> %b, <vscale x 2 x i64> %c, ptr %base) {
; CHECK-LABEL: and_i64_zero:
; CHECK: // %bb.0:
diff --git a/llvm/test/CodeGen/AArch64/sve2-intrinsics-fp-int-binary-logarithm-zeroing.ll b/llvm/test/CodeGen/AArch64/sve2-intrinsics-fp-int-binary-logarithm-zeroing.ll
index f61df82712730..4f748a7406c42 100644
--- a/llvm/test/CodeGen/AArch64/sve2-intrinsics-fp-int-binary-logarithm-zeroing.ll
+++ b/llvm/test/CodeGen/AArch64/sve2-intrinsics-fp-int-binary-logarithm-zeroing.ll
@@ -5,7 +5,7 @@
; FLOGB
;
-; NOTE: The %unused paramter ensures z0 is free, leading to a simpler test.
+; NOTE: The %unused parameter ensures z0 is free, leading to a simpler test.
define <vscale x 8 x i16> @flogb_f16(<vscale x 8 x i16> %unused, <vscale x 8 x i1> %pg, <vscale x 8 x half> %a) {
; CHECK-LABEL: flogb_f16:
; CHECK: // %bb.0:
diff --git a/llvm/test/MC/WebAssembly/block-assembly.s b/llvm/test/MC/WebAssembly/block-assembly.s
index ef3924d26057a..bedb8a017f7ef 100644
--- a/llvm/test/MC/WebAssembly/block-assembly.s
+++ b/llvm/test/MC/WebAssembly/block-assembly.s
@@ -7,7 +7,7 @@
block_branch_test:
.functype block_branch_test () -> ()
- # Block input paramter / return tests
+ # Block input parameter / return tests
i32.const 0
block (i32) -> (i32)
diff --git a/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.h b/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.h
index b7d14da05ee24..5a2cdc157fd93 100644
--- a/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.h
+++ b/llvm/lib/Target/PowerPC/PPCMachineFunctionInfo.h
@@ -131,9 +131,9 @@ class PPCFunctionInfo : public MachineFunctionInfo {
/// VectorParmsNum - The number of vector parameters.
unsigned VectorParmsNum = 0;
/// ParamtersType - Store all the parameter's type that are saved on
/// registers.
- SmallVector<ParamType, 32> ParamtersType;
+ SmallVector<ParamType, 32> ParametersType;
/// CRSpillFrameIndex - FrameIndex for CR spill slot for 32-bit SVR4.
int CRSpillFrameIndex = 0;
@@ -131,9 +131,9 @@ class PPCFunctionInfo : public MachineFunctionInfo {
/// VectorParmsNum - The number of vector parameters.
unsigned VectorParmsNum = 0;
- /// ParamtersType - Store all the parameter's type that are saved on
+ /// ParametersType - Store all the parameter's type that are saved on
/// registers.
diff --git a/llvm/unittests/DebugInfo/DWARF/DWARFFormValueTest.cpp b/llvm/unittests/DebugInfo/DWARF/DWARFFormValueTest.cpp
index 29d4db44e7cf9..98f2cbd8355c1 100644
--- a/llvm/unittests/DebugInfo/DWA...
[truncated]
``````````
</details>
https://github.com/llvm/llvm-project/pull/134092
More information about the llvm-commits
mailing list